@@ -1,4 +1,4 @@
-summarize_mat<-function(mat_main,ann_main,mat_supp,ann_supp,n_limit=50,extend=100000)
+summarize_mat<-function(mat_main,ann_main,mat_supp,ann_supp,n_limit=50,extend=100000,method="pca")
 {
   mat_main=as.matrix(mat_main)
   mod_main=mat_main
@@ -13,11 +13,18 @@ summarize_mat<-function(mat_main,ann_main,mat_supp,ann_supp,n_limit=50,extend=10
       PCA=mat_supp[ids,]
     }else
     {
-      PCA=prcomp(t(mat_supp[ids,]),.scale=T)$x[,1]
+      if (method=="max")
+      {
+        ids_max=ids[which.max(abs(cor(mat_main[i,],t(mat_supp[ids,]))))]
+        PCA=mat_supp[ids_max,]
+      }else
+      {
+        PCA=prcomp(t(mat_supp[ids,]),.scale=T)$x[,1]
+      }
     }
     if (cor(PCA,mat_main[i,])<0) {PCA=-PCA}
     mod_main[i,]=PCA
   }
   
   mod_main
-}
\ No newline at end of file
+}
